==> pytextrank-3.2.5.tar.gz: pytextrank-3.2.5/docs/ack.md <==
# Acknowledgements

## Contributors

Many thanks to our open source [sponsors](https://github.com/sponsors/ceteri);
and to our contributors:
[@louisguitton](https://github.com/louisguitton),
[@Ankush-Chander](https://github.com/Ankush-Chander),
[@tomaarsen](https://github.com/tomaarsen),
[@CaptXiong](https://github.com/CaptXiong),
[@Lord-V15](https://github.com/Lord-V15),
[@anna-droid-beep](https://github.com/anna-droid-beep),
[@dvsrepo](https://github.com/dvsrepo),
[@clabornd](https://github.com/clabornd),
[@dayalstrub-cma](https://github.com/dayalstrub-cma),
[@kavorite](https://github.com/kavorite),
[@0dB](https://github.com/0dB),
[@htmartin](https://github.com/htmartin),
[@williamsmj](https://github.com/williamsmj/),
[@mattkohl](https://github.com/mattkohl),
[@vanita5](https://github.com/vanita5),
[@HarshGrandeur](https://github.com/HarshGrandeur),
[@mnowotka](https://github.com/mnowotka),
[@kjam](https://github.com/kjam),
[@SaiThejeshwar](https://github.com/SaiThejeshwar),
[@laxatives](https://github.com/laxatives),
[@dimmu](https://github.com/dimmu), 
[@JasonZhangzy1757](https://github.com/JasonZhangzy1757), 
[@jake-aft](https://github.com/jake-aft),
[@junchen1992](https://github.com/junchen1992),
[@shyamcody](https://github.com/shyamcody),
[@chikubee](https://github.com/chikubee);
also to [@mihalcea](https://github.com/mihalcea) who leads outstanding NLP research work,
encouragement from the wonderful folks at Explosion who develop [spaCy](https://github.com/explosion/spaCy),
plus general support from [Derwen, Inc.](https://derwen.ai/)


## Project Lead

[Paco Nathan](https://derwen.ai/paco)
is lead committer on **pytextrank** and lead author for its documentation and tutorial.
By day he's the Managing Partner at [Derwen, Inc.](https://derwen.ai/)
Paco's formal background is in 
Mathematics (advisor: [Richard Cottle](https://engineering.stanford.edu/people/richard-cottle))
and
Computer Science (advisor: [Douglas Lenat](https://en.wikipedia.org/wiki/Douglas_Lenat)),
with additional work in Design and Linguistics.
His business experience includes: 
Director, VP, and CTO positions leading data teams and machine learning projects;
former CTO/Board member at two publicly-traded tech firms on NASDAQ OTC:BB;
and an equity partner at [Amplify Partners](https://derwen.ai/s/hcxhybks9nbh).
Cited in 2015 as one of the 
[Top 30 People in Big Data and Analytics](http://www.kdnuggets.com/2015/02/top-30-people-big-data-analytics.html)
by Innovation Enterprise.

  * ~40 years tech industry experience, ranging from Bell Labs
    to early-stage start-ups
  * 7+ years R&D in *neural networks* (incl. h/w accelerators) during 1980-90s
  * early "guinea pig" for Amazon AWS (2006), who led the first
    large-scale Hadoop use case on [cloud computing](../glossary/#cloud-computing) (2008)
  * former Director, Community Evangelism at Databricks (2014-2015) for
    [Apache Spark](https://spark.apache.org/)
  * lead committer on [kglab](https://derwen.ai/docs/kgl/);
    open source community work on 
    [Jupyter](https://jupyter.org/),
    [Ray](https://ray.io/),
    [Cascading](https://www.cascading.org/)
  * consultant to enterprise organizations for [data strategy](../glossary/#data-strategy);
    advisor to several AI start-ups, including
    [Recognai](https://derwen.ai/s/hk4g),
    [KUNGFU.AI](https://derwen.ai/s/rwg8prbgqp36),
    [Primer](https://derwen.ai/s/tm9jxzcm67hc)

As an author/speaker/instructor, Paco has taught many people (+9000) 
in industry across a range of topics –
[*data science*](../glossary/#data-science),
[*natural language*](../glossary/#natural-language),
[*cloud computing*](../glossary/#cloud-computing),
[*reinforcement learning*](../glossary/#reinforcement-learning),
[*computable content*](../glossary/#computable-content),
etc. –
and through guest lectures at 
Stanford, CMU, UC&nbsp;Berkeley,
U&nbsp;da&nbsp;Coruña, U&nbsp;Manchester,
KTH, NYU, GWU,
U&nbsp;Maryland, Cal&nbsp;Poly, UT/Austin,
Northeastern, U&nbsp;Virginia, CU&nbsp;Boulder.

<a href="https://stackoverflow.com/users/1698443/paco"><img src="https://stackoverflow.com/users/flair/1698443.png" width="208" height="58" alt="profile for Paco at Stack Overflow, Q&amp;A for professional and enthusiast programmers" title="profile for Paco at Stack Overflow, Q&amp;A for professional and enthusiast programmers"/></a>


## Attribution

Please use the following BibTeX entry for citing **pytextrank** if you use
it in your research or software:

```
@software{PyTextRank,
  author = {Paco Nathan},
  title = {{PyTextRank, a Python implementation of TextRank for phrase extraction and summarization of text documents}},
  year = 2016,
  publisher = {Derwen},
  doi = {10.5281/zenodo.4637885},
  url = {https://github.com/DerwenAI/pytextrank}
}

```

**DOI:** <https://doi.org/10.5281/zenodo.4637885>


## License and Copyright

Source code for **pytextrank** plus its logo, documentation, and examples
have an [MIT license](https://spdx.org/licenses/MIT.html) which is
succinct and simplifies use in commercial applications.

All materials herein are Copyright &copy; 2016-2023 Derwen, Inc.

[![logo for Derwen, Inc.](https://derwen.ai/static/block_logo.png)](https://derwen.ai/)


## Production Use Cases

  * [Derwen](https://derwen.ai/) and its client projects

==> pytextrank-3.3.0.tar.gz: pytextrank-3.3.0/docs/ack.md <==
# Acknowledgements

## Contributors

Many thanks to our open source [sponsors](https://github.com/sponsors/ceteri);
and to our contributors:
[@louisguitton](https://github.com/louisguitton),
[@Ankush-Chander](https://github.com/Ankush-Chander),
[@tomaarsen](https://github.com/tomaarsen),
[@CaptXiong](https://github.com/CaptXiong),
[@Lord-V15](https://github.com/Lord-V15),
[@anna-droid-beep](https://github.com/anna-droid-beep),
[@dvsrepo](https://github.com/dvsrepo),
[@clabornd](https://github.com/clabornd),
[@dayalstrub-cma](https://github.com/dayalstrub-cma),
[@kavorite](https://github.com/kavorite),
[@0dB](https://github.com/0dB),
[@htmartin](https://github.com/htmartin),
[@williamsmj](https://github.com/williamsmj/),
[@mattkohl](https://github.com/mattkohl),
[@vanita5](https://github.com/vanita5),
[@HarshGrandeur](https://github.com/HarshGrandeur),
[@mnowotka](https://github.com/mnowotka),
[@kjam](https://github.com/kjam),
[@SaiThejeshwar](https://github.com/SaiThejeshwar),
[@laxatives](https://github.com/laxatives),
[@dimmu](https://github.com/dimmu), 
[@JasonZhangzy1757](https://github.com/JasonZhangzy1757), 
[@jake-aft](https://github.com/jake-aft),
[@junchen1992](https://github.com/junchen1992),
[@shyamcody](https://github.com/shyamcody),
[@chikubee](https://github.com/chikubee);
also to [@mihalcea](https://github.com/mihalcea) who leads outstanding NLP research work,
encouragement from the wonderful folks at Explosion who develop [spaCy](https://github.com/explosion/spaCy),
plus general support from [Derwen, Inc.](https://derwen.ai/)


## Project Lead

[Paco Nathan](https://derwen.ai/paco)
is lead committer on **pytextrank** and lead author for its documentation and tutorial.
By day he's the Managing Partner at [Derwen, Inc.](https://derwen.ai/)
Paco's formal background is in 
Mathematics (advisor: [Richard Cottle](https://engineering.stanford.edu/people/richard-cottle))
and
Computer Science (advisor: [Douglas Lenat](https://en.wikipedia.org/wiki/Douglas_Lenat)),
with additional work in Design and Linguistics.
His business experience includes: 
Director, VP, and CTO positions leading data teams and machine learning projects;
former CTO/Board member at two publicly-traded tech firms on NASDAQ OTC:BB.
Cited in 2015 as one of the 
[Top 30 People in Big Data and Analytics](http://www.kdnuggets.com/2015/02/top-30-people-big-data-analytics.html)
by Innovation Enterprise.

  * ~40 years tech industry experience, ranging from Bell Labs
    to early-stage start-ups
  * 7+ years R&D in *neural networks* (incl. h/w accelerators) during 1980-90s
  * early "guinea pig" for Amazon AWS (2006), who led the first
    large-scale Hadoop use case on [cloud computing](../glossary/#cloud-computing) (2008)
  * former Director, Community Evangelism at Databricks (2014-2015) for
    [Apache Spark](https://spark.apache.org/)
  * lead committer on [kglab](https://derwen.ai/docs/kgl/);
    open source community work on 
    [Jupyter](https://jupyter.org/),
    [Ray](https://ray.io/),
    [Cascading](https://www.cascading.org/)
  * consultant to enterprise organizations for [data strategy](../glossary/#data-strategy);
    advisor to several AI start-ups, including
    [Argilla](https://derwen.ai/s/mz2xj9bsz2jx),
    [KUNGFU.AI](https://derwen.ai/s/rwg8prbgqp36),
    [DataSpartan](https://derwen.ai/s/hxsfttck3dkx)

As an author/speaker/instructor, Paco has taught many people (+9000) 
in industry across a range of topics –
[*data science*](../glossary/#data-science),
[*natural language*](../glossary/#natural-language),
[*cloud computing*](../glossary/#cloud-computing),
[*computable content*](../glossary/#computable-content),
etc. –
and through guest lectures at 
Stanford, CMU, UC&nbsp;Berkeley,
U&nbsp;da&nbsp;Coruña, U&nbsp;Manchester,
KTH, NYU, GWU,
U&nbsp;Maryland, Cal&nbsp;Poly, UT/Austin,
Northeastern, U&nbsp;Virginia, CU&nbsp;Boulder.

<a href="https://stackoverflow.com/users/1698443/paco"><img src="https://stackoverflow.com/users/flair/1698443.png" width="208" height="58" alt="profile for Paco at Stack Overflow, Q&amp;A for professional and enthusiast programmers" title="profile for Paco at Stack Overflow, Q&amp;A for professional and enthusiast programmers"/></a>


## Attribution

Please use the following BibTeX entry for citing **pytextrank** if you use
it in your research or software:

```
@software{PyTextRank,
  author = {Paco Nathan},
  title = {{PyTextRank, a Python implementation of TextRank for phrase extraction and summarization of text documents}},
  year = 2016,
  publisher = {Derwen},
  doi = {10.5281/zenodo.4637885},
  url = {https://github.com/DerwenAI/pytextrank}
}

```

**DOI:** <https://doi.org/10.5281/zenodo.4637885>


## License and Copyright

Source code for **pytextrank** plus its logo, documentation, and examples
have an [MIT license](https://spdx.org/licenses/MIT.html) which is
succinct and simplifies use in commercial applications.

All materials herein are Copyright &copy; 2016-2024 Derwen, Inc.

[![logo for Derwen, Inc.](https://derwen.ai/static/design/block_logo.png)](https://derwen.ai/)


## Production Use Cases

  * [Derwen](https://derwen.ai/) and its client projects
